@@ -48,7 +48,7 @@ void _dummy_SIGHUP_handler(int)
 
 //***************************************************************************
 Kwave::WorkerThread::WorkerThread(Kwave::Runnable *runnable, QVariant params)
-    :QThread(Q_NULLPTR),
+    :QThread(nullptr),
      m_runnable(runnable),
      m_params(params),
      m_lock(), m_lock_sighup(),
@@ -174,3 +174,5 @@ void Kwave::WorkerThread::run()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_WorkerThread.cpp"
