@@ -19,6 +19,7 @@
 #define STREAM_OBJECT_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QObject>
@@ -29,7 +30,7 @@ class QVariant;
 namespace Kwave
 {
 
-    class Q_DECL_EXPORT StreamObject: public QObject
+    class LIBKWAVE_EXPORT StreamObject: public QObject
     {
         Q_OBJECT
     public:
@@ -38,10 +39,10 @@ namespace Kwave
          *
          * @param parent a parent object, passed to QObject (optional)
          */
-        explicit StreamObject(QObject *parent = Q_NULLPTR);
+        explicit StreamObject(QObject *parent = nullptr);
 
         /** Destructor */
-        virtual ~StreamObject();
+        ~StreamObject() override;
 
         /**
          * Returns the default number of tracks that the source provides
@@ -58,7 +59,7 @@ namespace Kwave
          */
         virtual Kwave::StreamObject * operator [] (unsigned int track)
         {
-            return (track == 0) ? this : Q_NULLPTR;
+            return (track == 0) ? this : nullptr;
         }
 
         /**
