@@ -26,7 +26,7 @@
 
 //***************************************************************************
 Kwave::LowPassFilter::LowPassFilter()
-    :Kwave::SampleSource(Q_NULLPTR), m_buffer(blockSize()),
+    :Kwave::SampleSource(nullptr), m_buffer(blockSize()),
     m_f_cutoff(M_PI)
 {
     initFilter();
@@ -213,3 +213,5 @@ void Kwave::LowPassFilter::setFrequency(const QVariant fc)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_LowPassFilter.cpp"
