@@ -29,14 +29,11 @@
 #include "libkwave/Plugin.h"
 #include "libkwave/Sample.h"
 
-class QStringList;
-
 namespace Kwave
 {
     class PlaybackController;
     class PlayBackDevice;
     class PlayBackDialog;
-    class PluginContext;
     class SampleSink;
 
     class PlayBackPlugin :public Kwave::Plugin,
@@ -53,28 +50,28 @@ namespace Kwave
         PlayBackPlugin(QObject *parent, const QVariantList &args);
 
         /** Destructor */
-        virtual ~PlayBackPlugin() Q_DECL_OVERRIDE;
+        ~PlayBackPlugin() override;
 
         /**
          * Gets called when the plugin is first loaded and connects itself
          * to the playback controller and the current signal.
          */
-        virtual void load(QStringList &params) Q_DECL_OVERRIDE;
+        void load(QStringList &params) override;
 
         /**
          * Gets called before the plugin is unloaded.
          */
-        virtual void unload() Q_DECL_OVERRIDE;
+        void unload() override;
 
         /** @see Kwave::Plugin::setup() */
         virtual QStringList *setup(QStringList &previous_params)
-            Q_DECL_OVERRIDE;
+            override;
 
         /**
          * Starts a playback test sequence
          * @param params list of strings with parameters (unused)
          */
-        virtual void run(QStringList params) Q_DECL_OVERRIDE;
+        void run(QStringList params) override;
 
     signals:
 
@@ -104,7 +101,7 @@ namespace Kwave
          * @return a new PlayBackDevice or 0 if failed
          */
         virtual Kwave::PlayBackDevice *createDevice(
-            Kwave::playback_method_t method) Q_DECL_OVERRIDE;
+            Kwave::playback_method_t method) override;
 
         /**
          * Returns a list of supported playback methods.
@@ -112,7 +109,7 @@ namespace Kwave
          *         "any" or "invalid"
          */
         virtual QList<Kwave::playback_method_t> supportedMethods()
-            Q_DECL_OVERRIDE;
+            override;
 
     private:
 
