@@ -68,7 +68,7 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
     // create the setup dialog
     sample_index_t selection_left  = 0;
     sample_index_t selection_right = 0;
-    selection(Q_NULLPTR, &selection_left, &selection_right, false);
+    selection(nullptr, &selection_left, &selection_right, false);
 
     // enable the "selection only" checkbox only if there is something
     // selected but not everything
@@ -93,7 +93,7 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
             m_selection_only,
             enable_selection_only
         );
-        if (!dialog) return Q_NULLPTR;
+        if (!dialog) return nullptr;
 
     // connect the signals/slots from the plugin and the dialog
     connect(dialog, SIGNAL(sigSelectionChanged(QString,
@@ -107,7 +107,7 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
     dialog->emitUpdate();
     if ((dialog->exec() != QDialog::Accepted) || !dialog) {
         delete dialog;
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     QStringList *list = new(std::nothrow) QStringList();
@@ -120,7 +120,7 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
         if (url.isEmpty()) {
             delete dialog;
             delete list;
-            return Q_NULLPTR;
+            return nullptr;
         }
         QString name = url.path();
         QFileInfo path(name);
@@ -130,9 +130,7 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
             QString ext = dialog->selectedExtension();
             QStringList extensions = ext.split(_(" "));
             ext = extensions.first();
-            name += ext.midRef(1);
-            path = name;
-            url.setPath(name);
+            name += ext.mid(1);
         }
 
         name     = Kwave::Parser::escape(name);
@@ -153,7 +151,7 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
         );
     }
 
-    if (dialog) delete dialog;
+    delete dialog;
     return list;
 }
 
@@ -201,7 +199,7 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
     // determine the selection settings
     sample_index_t selection_left  = 0;
     sample_index_t selection_right = 0;
-    selection(Q_NULLPTR, &selection_left, &selection_right, false);
+    selection(nullptr, &selection_left, &selection_right, false);
 
     bool selected_something = (selection_left != selection_right);
     bool selected_all = ( (selection_left == 0) &&
@@ -215,7 +213,7 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
 
     // get the index range
     scanBlocksToSave(base, selection_only);
-    unsigned int count = m_block_info.count();
+    unsigned int count = static_cast<unsigned int>(m_block_info.count());
     unsigned int first = firstIndex(path, base, ext, m_pattern,
                                     m_numbering_mode, count);
 
@@ -319,7 +317,7 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
     // save the current selection, we have to restore it afterwards!
     sample_index_t saved_selection_left  = 0;
     sample_index_t saved_selection_right = 0;
-    selection(Q_NULLPTR, &saved_selection_left, &saved_selection_right, false);
+    selection(nullptr, &saved_selection_left, &saved_selection_right, false);
 
     // now we can loop over all blocks and save them
     sample_index_t block_start;
@@ -459,7 +457,7 @@ void Kwave::SaveBlocksPlugin::scanBlocksToSave(const QString &base,
     Kwave::Label label = (it.hasNext()) ? it.next() : Kwave::Label();
 
     if (selection_only) {
-        selection(Q_NULLPTR, &selection_left, &selection_right, true);
+        selection(nullptr, &selection_left, &selection_right, true);
     } else {
         selection_left  = 0;
         selection_right = signalLength() - 1;
@@ -657,6 +655,7 @@ unsigned int Kwave::SaveBlocksPlugin::firstIndex(const QString &path,
             }
             break;
         }
+        DEFAULT_IMPOSSIBLE;
     }
 
     return first;
@@ -693,12 +692,12 @@ QString Kwave::SaveBlocksPlugin::findBase(const QString &filename,
                                 QRegularExpression::CaseInsensitiveOption);
 
     QString p = QRegularExpression::escape(pattern);
-    int idx_nr       = p.indexOf(rx_nr);
-    int idx_count    = p.indexOf(rx_count);
-    int idx_total    = p.indexOf(rx_total);
-    int idx_filename = p.indexOf(rx_filename);
-    int idx_fileinfo = p.indexOf(rx_fileinfo);
-    int idx_title    = p.indexOf(rx_fileinfo);
+    qsizetype idx_nr       = p.indexOf(rx_nr);
+    qsizetype idx_count    = p.indexOf(rx_count);
+    qsizetype idx_total    = p.indexOf(rx_total);
+    int       idx_filename = static_cast<int>(p.indexOf(rx_filename));
+    qsizetype idx_fileinfo = p.indexOf(rx_fileinfo);
+    qsizetype idx_title    = p.indexOf(rx_fileinfo);
     p.replace(rx_nr,       _("(\\d+)"));
     p.replace(rx_count,    _("(\\d+)"));
     p.replace(rx_total,    _("(\\d+)"));
@@ -706,8 +705,8 @@ QString Kwave::SaveBlocksPlugin::findBase(const QString &filename,
     p.replace(rx_fileinfo, _("(.+)"));
     p.replace(rx_title,    _("(.+)"));
 
-    int max = 0;
-    for (int i = 0; i < pattern.length(); i++) {
+    qsizetype max = 0;
+    for (qsizetype i = 0; i < pattern.length(); i++) {
         if (idx_nr       == max) max++;
         if (idx_count    == max) max++;
         if (idx_total    == max) max++;
@@ -747,7 +746,7 @@ QString Kwave::SaveBlocksPlugin::firstFileName(const QString &filename,
     // now we have a new name, base and extension
     // -> find out the numbering, min/max etc...
     scanBlocksToSave(base, selection_only);
-    unsigned int count = m_block_info.count();
+    unsigned int count = static_cast<unsigned int>(m_block_info.count());
     unsigned int first = firstIndex(path, base, ext, pattern, mode, count);
     unsigned int total = first + count - 1;
 
@@ -768,3 +767,5 @@ void Kwave::SaveBlocksPlugin::updateExample(const QString &filename,
 #include "SaveBlocksPlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_SaveBlocksPlugin.cpp"
